# GTDB Validation Toolkit

[![version status](https://img.shields.io/pypi/v/gtdb_validation_tk.svg)](https://pypi.python.org/pypi/gtdb_validation_tk)
[![ace-internal](https://img.shields.io/conda/vn/ace-internal/gtdb_validation_tk.svg?color=green)](https://anaconda.org/ace-internal/gtdb_validation_tk)
[![Downloads](https://pepy.tech/badge/gtdb_validation_tk)](https://pepy.tech/project/gtdb_validation_tk)
[![Downloads](https://pepy.tech/badge/gtdb_validation_tk/month)](https://pepy.tech/project/gtdb_validation_tk/month)

This toolkit provides functionality for validation the GTDB Taxonomy. It is primarily intended to be used by the GTDB curation team, but has been made available in case others find it useful. 

## Install

The simplest way to install this package is through pip:
> sudo pip install gtdb_validation_tk

## Cite

If you find this package useful, please cite this git repository (https://github.com/Ecogenomics/gtdb_validation_tk)

## Copyright

Copyright © 2019 Donovan Parks. See LICENSE for further details.
